@@ -6,8 +6,8 @@
 ;; Author: Campbell Barton <ideasman42@gmail.com>
 
 ;; URL: https://codeberg.org/ideasman42/emacs-mono-complete
-;; Package-Version: 20251126.1132
-;; Package-Revision: 71d46dc015cc
+;; Package-Version: 20260105.209
+;; Package-Revision: 12eb3f326f49
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -73,7 +73,7 @@ When non-nil this must be a list of 3 symbols referencing functions.
 (defcustom mono-complete-cache-directory
   (locate-user-emacs-file "mono-complete" ".emacs-mono-complete")
   "The directory to store mono-complete cache data."
-  :type 'string)
+  :type 'directory)
 
 (defface mono-complete-preview-face '((t (:foreground "#ffff00" :background "#000000")))
   "Face for the preview."
